pub struct PositionConfig {
pub buy_amount_lp: u64,
pub jito_tip_buy_lp: u64,
pub hold_time_ms: u32,
pub jito_tip_sell_lp: u64,
pub use_stop_loss: bool,
pub trailing_stop_loss: bool,
pub stop_loss_threshold_lp: u64,
pub wallet_copying: Pubkey,
pub slippage_lps: u64,
}Expand description
Configuration for copy trading a specific wallet, defining position sizing and risk management. Each tracked wallet has its own configuration specifying buy amounts, hold times, stop-loss thresholds, and slippage tolerances.
Fields
buy_amount_lp: u64jito_tip_buy_lp: u64hold_time_ms: u32jito_tip_sell_lp: u64use_stop_loss: booltrailing_stop_loss: boolstop_loss_threshold_lp: u64wallet_copying: Pubkeyslippage_lps: u64Trait Implementations
Sourceimpl Clone for PositionConfig
impl Clone for PositionConfig
Sourcefn clone(&self) -> PositionConfig
fn clone(&self) -> PositionConfig
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PositionConfig
impl Debug for PositionConfig
impl Copy for PositionConfig