pub fn set_wallet_configs_from_pl_df(
position_manager: &mut PositionManager,
df: &DataFrame,
)Expand description
Set wallet configurations from a Polars DataFrame. Clears existing wallet configs and loads new configurations from a DataFrame containing wallet addresses and their position configuration parameters.